.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/<USER>/vyze.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/<USER>/vyze
    .. image:: https://readthedocs.org/projects/vyze/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://vyze.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/<USER>/vyze/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/<USER>/vyze
    .. image:: https://img.shields.io/pypi/v/vyze.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/vyze/
    .. image:: https://img.shields.io/conda/vn/conda-forge/vyze.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/vyze
    .. image:: https://pepy.tech/badge/vyze/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/vyze

 .. image:: https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter
     :alt: Twitter
     :target: https://twitter.com/bitspark

|

====
VYZE
====

    Data backbone for multi-component software systems.

VYZE serves as a SaaS database and communication hub for applications of different levels of complexity.
